/*
 * UtilityFunctions.c
 *
 *  Created on: 05 apr 2017
 *      Author: Giovanni Trotta
 */

#include "UtilityFunctions.h"


extern TIM_HandleTypeDef TimHandle;

static uint16_t currentPeriod=PERIOD_1;

void Init_Led(){
	 /* -1- Enable GPIOE Clock (to be able to program the configuration registers) */
	  __HAL_RCC_GPIOE_CLK_ENABLE();
	  GPIO_InitTypeDef  GPIO_LedStruct;
	  /* -2- Configure PE.8 to PE.15 IOs in output push-pull mode to drive external LEDs */
	  GPIO_LedStruct.Pin = (GPIO_PIN_15 |GPIO_PIN_14 |GPIO_PIN_13 |GPIO_PIN_12 |GPIO_PIN_11 | GPIO_PIN_10 | GPIO_PIN_9 | GPIO_PIN_8);
	  GPIO_LedStruct.Mode = GPIO_MODE_OUTPUT_PP;
	  GPIO_LedStruct.Pull = GPIO_PULLUP;
	  GPIO_LedStruct.Speed = GPIO_SPEED_FREQ_HIGH;

	  HAL_GPIO_Init(GPIOE, &GPIO_LedStruct);

}

////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////


void Init_TIM_IT(uint16_t period){

    /*Configure the TIM2 IRQ priority */
	HAL_NVIC_SetPriority(TIM2_IRQn, 0 ,0U);

  	 /* Enable the TIM2 global Interrupt */
  	HAL_NVIC_EnableIRQ(TIM2_IRQn);

	__HAL_RCC_TIM2_CLK_ENABLE();

	TimHandle.Instance = TIM2;
	TimHandle.Init.Prescaler=18000-1;
	TimHandle.Init.CounterMode=TIM_COUNTERMODE_UP;
	TimHandle.Init.ClockDivision=TIM_CLOCKDIVISION_DIV1;
	TimHandle.Init.Period=period;

	HAL_TIM_Base_Init(&TimHandle);

	HAL_TIM_Base_Start_IT(&TimHandle);

}

void TIM2_IRQHandler(void)
{
  HAL_TIM_IRQHandler(&TimHandle);
}

void HAL_TIM_PeriodElapsedCallback(TIM_HandleTypeDef *htim)
{
	HAL_GPIO_TogglePin(GPIOE, GPIO_PIN_15);
	trace_printf("Into TIM Callback!!! \n");
}


////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////

void Init_Button_IT(){

	 HAL_NVIC_SetPriority(EXTI0_IRQn, 0, 0U);
	 HAL_NVIC_EnableIRQ(EXTI0_IRQn);
	 GPIO_InitTypeDef  GPIO_ButtonStruct;
	 /* -1- Enable GPIOA Clock (to be able to program the configuration registers) */
	  __HAL_RCC_GPIOA_CLK_ENABLE();

	  GPIO_ButtonStruct.Pin = GPIO_PIN_0;
	  GPIO_ButtonStruct.Mode = GPIO_MODE_IT_RISING;
	  GPIO_ButtonStruct.Pull = GPIO_NOPULL;
	  GPIO_ButtonStruct.Speed = GPIO_SPEED_FREQ_HIGH;

	  HAL_GPIO_Init(GPIOA, &GPIO_ButtonStruct);

}


void EXTI0_IRQHandler(void)
{
	  HAL_GPIO_EXTI_IRQHandler(GPIO_PIN_0);
}

void HAL_GPIO_EXTI_Callback (uint16_t GPIO_Pin)
{

    	if(currentPeriod==PERIOD_1){
    	   currentPeriod=PERIOD_2;
    	}else{
    	   currentPeriod=PERIOD_1;
    	}

    	Init_TIM_IT(currentPeriod);
    	trace_printf("Into EXTI Callback!!! \n");

}
